Struct amazon_sp_orders::models::orders_list::OrdersList
source · [−]pub struct OrdersList {
pub orders: Vec<Order>,
pub next_token: Option<String>,
pub last_updated_before: Option<String>,
pub created_before: Option<String>,
}Expand description
OrdersList : A list of orders along with additional information to make subsequent API calls.
Fields
orders: Vec<Order>A list of orders.
next_token: Option<String>When present and not empty, pass this string token in the next request to return the next response page.
last_updated_before: Option<String>A date used for selecting orders that were last updated before (or at) a specified time. An update is defined as any change in order status, including the creation of a new order. Includes updates made by Amazon and by the seller. All dates must be in ISO 8601 format.
created_before: Option<String>A date used for selecting orders created before (or at) a specified time. Only orders placed before the specified time are returned. The date must be in ISO 8601 format.
Implementations
sourceimpl OrdersList
impl OrdersList
sourcepub fn new(orders: Vec<Order>) -> OrdersList
pub fn new(orders: Vec<Order>) -> OrdersList
A list of orders along with additional information to make subsequent API calls.